@@ -1,6 +1,6 @@
 package MARC::Moose::Reader::File::Marcxml;
 # ABSTRACT: File reader for MARCXML file
-$MARC::Moose::Reader::File::Marcxml::VERSION = '1.0.29';
+$MARC::Moose::Reader::File::Marcxml::VERSION = '1.0.30';
 use Moose;
 
 use Carp;
@@ -30,7 +30,7 @@ sub read {
     $raw =~ s/<(\/*)collection.*>//;
 
     # End of file
-    return unless $raw =~ /<record>/;
+    return unless $raw =~ /<record.*>/;
 
     $self->parser->parse( $raw );
 }
@@ -51,7 +51,7 @@ MARC::Moose::Reader::File::Marcxml - File reader for MARCXML file
 
 =head1 VERSION
 
-version 1.0.29
+version 1.0.30
 
 =head1 DESCRIPTION
 
